==> nui_core-1.0.9.tar.gz: lib/ui/nui_image_util.dart <==
import 'dart:typed_data';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter_svg/svg.dart';
import 'package:line_awesome_flutter/line_awesome_flutter.dart';
import 'dart:io';
import 'package:nui_core/color/nui_colors.dart';

Widget loadImage(String imageUrl, {BoxFit fit = BoxFit.cover, double? width, double? height, Widget? placeHolder, Widget? errorWidget}){
  return NUIImageUtil.loadImage(imageUrl, width: width, height:height, placeHolder: placeHolder, errorWidget: errorWidget, fit: fit);
}

Widget loadImageLocal(String path, double width, double height, {BoxFit fit:BoxFit.cover, Uint8List? thumbdata}){
  return NUIImageUtil.loadImageLocal(path, width, height, thumbdata: thumbdata);
}

Widget loadSvg(String filename, {double? width, double? height, Color? color, String? package, BoxFit fit: BoxFit.scaleDown}){
  return NUIImageUtil.loadSvg(filename, width: width, height: height, color: color, package: package, fit: fit);
}

ImageProvider loadImageProvider(String imageUrl){
  return NUIImageUtil.loadImageProvider(imageUrl);
}

class NUIImageUtil{
  NUIImageUtil._builder();

  static Widget loadImage(String imageUrl, {BoxFit fit: BoxFit.cover, double? width, double? height, Widget? placeHolder, Widget? errorWidget}){
    final targetPlaceHolder = placeHolder ?? Center(child: SizedBox(height: 30.0, width: 30.0, child: CircularProgressIndicator(strokeWidth: 1.5, valueColor: new AlwaysStoppedAnimation<Color>(NUIColors.NUIDarkGrayOutline), backgroundColor: NUIColors.NUISkeletalGray)));
    return CachedNetworkImage(
      imageUrl: imageUrl,
      width: width,
      height: height,
      fit: fit,
      placeholder: (context, url) => targetPlaceHolder,
      errorWidget: (context, url, error) => errorWidget ?? Center(child: Icon(LineAwesomeIcons.exclamation, color: NUIColors.NUISkeletalGray, size: 24,)),
    );
  }

  static ImageProvider loadImageProvider(String imageUrl){
    return CachedNetworkImageProvider(imageUrl);
  }

  static Widget loadSvg(String filename, {double? width, double? height, Color? color, String? package, BoxFit fit = BoxFit.scaleDown}){
    return SvgPicture.asset('assets/images/$filename', height: width, width: height, color: color, package: package, fit: fit);
  }

  static Widget loadImageLocal(String path, double width, double height, {BoxFit fit = BoxFit.cover, Uint8List? thumbdata}){
    if(thumbdata == null) return Image.file(File(path), width: width, height: height, fit: fit,);
    return Image.memory(thumbdata, width: width, height: height, fit: fit);
  }

}

==> nui_core-1.0.15.tar.gz: lib/ui/nui_image_util.dart <==
import 'dart:typed_data';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter_svg/svg.dart';
import 'package:line_awesome_flutter/line_awesome_flutter.dart';
import 'dart:io';
import 'package:nui_core/color/nui_colors.dart';

Widget loadImage(String imageUrl, {BoxFit fit = BoxFit.cover, double? width, double? height, Widget? placeHolder, Widget? errorWidget}){
  return NUIImageUtil.loadImage(imageUrl, width: width, height:height, placeHolder: placeHolder, errorWidget: errorWidget, fit: fit);
}

Widget loadImageLocal(String path, double width, double height, {BoxFit fit = BoxFit.cover, Uint8List? thumbdata}){
  return NUIImageUtil.loadImageLocal(path, width, height, thumbdata: thumbdata);
}

Widget loadSvg(String filename, {double? width, double? height, Color? color, String? package, BoxFit fit: BoxFit.scaleDown}){
  return NUIImageUtil.loadSvg(filename, width: width, height: height, color: color, package: package, fit: fit);
}

ImageProvider loadImageProvider(String imageUrl){
  return NUIImageUtil.loadImageProvider(imageUrl);
}

class NUIImageUtil{
  NUIImageUtil._builder();

  static Widget loadImage(String imageUrl, {BoxFit fit: BoxFit.cover, double? width, double? height, Widget? placeHolder, Widget? errorWidget}){
    final targetPlaceHolder = placeHolder ?? Center(child: SizedBox(height: 30.0, width: 30.0, child: CircularProgressIndicator(strokeWidth: 1.5, valueColor: new AlwaysStoppedAnimation<Color>(NUIColors.NUIDarkGrayOutline), backgroundColor: NUIColors.NUISkeletalGray)));
    return CachedNetworkImage(
      imageUrl: imageUrl,
      width: width,
      height: height,
      fit: fit,
      placeholder: (context, url) => targetPlaceHolder,
      errorWidget: (context, url, error) => errorWidget ?? Center(child: Icon(LineAwesomeIcons.exclamation, color: NUIColors.NUISkeletalGray, size: 24,)),
    );
  }

  static ImageProvider loadImageProvider(String imageUrl){
    return CachedNetworkImageProvider(imageUrl);
  }

  static Widget loadSvg(String filename, {double? width, double? height, Color? color, String? package, BoxFit fit = BoxFit.scaleDown}){
    return SvgPicture.asset('assets/images/$filename', height: width, width: height, package: package, fit: fit, );
  }

  static Widget loadImageLocal(String path, double width, double height, {BoxFit fit = BoxFit.cover, Uint8List? thumbdata}){
    if(thumbdata == null) return Image.file(File(path), width: width, height: height, fit: fit,);
    return Image.memory(thumbdata, width: width, height: height, fit: fit);
  }

}
